@@ -12,6 +12,7 @@ __all__ = [
     "get_diagnostics",
 ]
 
+
 class Diagnostics:
     """Information for the library."""
 
@@ -66,11 +67,13 @@ class Diagnostics:
 SUBSCRIBER_DIAGNOSTICS = Diagnostics()
 EVENT_DIAGNOSTICS = Diagnostics()
 EVENT_MEDIA_DIAGNOSTICS = Diagnostics()
+STREAMING_MANAGER_DIAGNOSTICS = Diagnostics()
 
 MAP = {
     "subscriber": SUBSCRIBER_DIAGNOSTICS,
     "event": EVENT_DIAGNOSTICS,
     "event_media": EVENT_MEDIA_DIAGNOSTICS,
+    "streaming_manager": STREAMING_MANAGER_DIAGNOSTICS,
 }
 
 
@@ -87,7 +90,7 @@ def get_diagnostics() -> dict[str, Any]:
 
 REDACT_KEYS = {
     "name",
-    "customName",
+    "custom_name",
     "displayName",
     "parent",
     "assignee",
