@@ -17,6 +17,14 @@ class AuthException(ApiException):
     """Raised due to auth problems talking to API or subscriber."""
 
 
+class NotFoundException(ApiException):
+    """Raised when the API returns an error that a resource was not found."""
+
+
+class ApiForbiddenException(ApiException):
+    """Raised when the user is not authorized to perform a specific function."""
+
+
 class ConfigurationException(GoogleNestException):
     """Raised due to misconfiguration problems."""
 
